from swap_user.to_phone_otp.base_managers import BasePhoneOTPUserManager


class PhoneOTPUserManager(BasePhoneOTPUserManager):
    """
    Concrete implementation of manager for PhoneOTPUser.
    """

    pass
